def date_to_number(month: int, day: int) -> int:
    """
    月日を数値形式に変換する関数

    Args:
        month (int): 月 (1-12)
        day (int): 日 (1-31)

    Returns:
        int: 月日を組み合わせた数値 (例: 1月1日 → 101, 12月1日 → 1201)

    Raises:
        ValueError: 月が1-12の範囲外、または日が1-31の範囲外の場合
    """
    # 入力値の検証
    if not 1 <= month <= 12:
        raise ValueError('月は1から12の間で指定してください')
    if not 1 <= day <= 31:
        raise ValueError('日は1から31の間で指定してください')

    # 月が1桁の場合は1桁のまま、2桁の場合は2桁で表示
    month_str = str(month)
    # 日は必ず2桁で表示（1桁の場合は0埋め）
    day_str = str(day).zfill(2)

    return int(month_str + day_str)


def get_all_date_numbers() -> list[int]:
    """
    1月1日から12月31日までのすべての日付の数値リストを生成する関数

    Returns:
        list[int]: 日付の数値リスト (例: [101, 102, ..., 1231])
    """
    # 各月の日数
    days_in_month = {
        1: 31, 2: 28, 3: 31, 4: 30, 5: 31, 6: 30,
        7: 31, 8: 31, 9: 30, 10: 31, 11: 30, 12: 31
    }
    
    result = []
    for month in range(1, 13):
        for day in range(1, days_in_month[month] + 1):
            result.append(date_to_number(month, day))
    
    return result


# 使用例
if __name__ == '__main__':
    # 個別の日付変換の例
    print(date_to_number(1, 1))    # 101
    print(date_to_number(3, 15))   # 315
    print(date_to_number(12, 1))   # 1201

    # すべての日付数値のリストを生成
    all_dates = get_all_date_numbers()
    print("\nすべての日付数値:")
    print(f"リストの長さ: {len(all_dates)}") # 365日分
    print(f"最初の5つの数値: {all_dates[:5]}")  # [101, 102, 103, 104, 105]
    print(f"最後の5つの数値: {all_dates[-5:]}")  # [1227, 1228, 1229, 1230, 1231] 